package com.agilecontrol.nea.core.control.web.binhandler;

import com.agilecontrol.nea.core.control.web.UserWebImpl;
import com.agilecontrol.nea.core.control.web.WebUtils;
import com.agilecontrol.nea.core.control.web.binhandler.BinaryHandler;
import com.agilecontrol.nea.core.report.ReportUtils;
import com.agilecontrol.nea.core.util.ConfigValues;
import com.agilecontrol.nea.util.NDSException;
import com.agilecontrol.nea.util.Tools;
import com.agilecontrol.nea.util.Validator;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.fileupload.DiskFileUpload;
import org.apache.commons.fileupload.FileItem;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class Upload implements BinaryHandler {

   private static final Logger log = LoggerFactory.getLogger(Upload.class);
   private static final String CONTENT_TYPE = "text/html; charset=UTF-8";


   public void init(ServletContext context) {
   }

   public void process(HttpServletRequest request, HttpServletResponse response) throws Exception {
      boolean isOK = false;
      HashMap map = new HashMap();

      try {
         UserWebImpl script = null;
         script = (UserWebImpl)WebUtils.getSessionContextManager(request.getSession(true)).getActor("nea.web.authorization");
         if(script == null || script.isGuest()) {
            throw new NDSException("guest not allowed");
         }

         DiskFileUpload out = new DiskFileUpload();
         out.setSizeMax((long)(ConfigValues.UPLOAD_MAX_SIZE_FILE * 1024));
         List fileItems = out.parseRequest(request);
         Iterator iter = fileItems.iterator();
         InputStream in = null;
         String fileName = "";

         while(iter.hasNext()) {
            FileItem ru = (FileItem)iter.next();
            if(!ru.isFormField()) {
               in = ru.getInputStream();
               fileName = ru.getName();
               if(fileName != null) {
                  int name = fileName.lastIndexOf("\\");
                  if(name > 0) {
                     fileName = fileName.substring(name + 1);
                  }

                  name = fileName.lastIndexOf("/");
                  if(name > 0) {
                     fileName = fileName.substring(name + 1);
                  }
               }
            } else {
               map.put(ru.getFieldName(), ru.getString());
            }
         }

         if(in != null) {
            ReportUtils ru1 = new ReportUtils(request);
            String name1 = ru1.getUserName();
            String svrPath = ru1.getExportRootPath() + File.separator + ru1.getUser().getClientDomain() + File.separator + script.getUserId();
            if(fileName.contains("..") || fileName.contains("/") || fileName.contains("\\")) {
               throw new IllegalArgumentException("Illegal file name");
            }

            String filePath = svrPath + File.separator + fileName;
            File file = new File(filePath);
            FileOutputStream out1 = null;
            out1 = new FileOutputStream(file);
            this.copyContents(in, out1);
            out1.flush();
            out1.close();
            isOK = true;
            log.debug("save to " + file.getAbsolutePath() + " (" + Tools.formatSize(file.length()) + ")");
         }
      } catch (Throwable var17) {
         log.error("fail to do upload ", var17);
      }

      String script1;
      if(isOK) {
         script1 = (String)map.get("onsuccess");
         if(Validator.isNull(script1)) {
            script1 = "window.parent.window.stopUpload(0);";
         }
      } else {
         script1 = (String)map.get("onfail");
         if(Validator.isNull(script1)) {
            script1 = "window.parent.window.stopUpload(1);";
         }
      }

      response.setContentType("text/html; charset=UTF-8");
      PrintWriter out2 = response.getWriter();
      out2.print("<html><body><script language=\'javascript\' type=\'text/javascript\'>");
      out2.print(script1);
      out2.println("</script></body></html>");
   }

   private void copyContents(InputStream in, OutputStream out) throws IOException {
      byte[] b = new byte[16384];

      int bInt;
      while((bInt = in.read(b, 0, b.length)) != -1) {
         out.write(b, 0, bInt);
      }

      out.flush();
   }

}
